ConfigError

Enum ConfigError 

#[non_exhaustive]
pub enum ConfigError { Frozen, NotFound(String), PathParse { cause: Box<dyn Error + Send + Sync>, }, FileParse { uri: Option<String>, cause: Box<dyn Error + Send + Sync>, }, Type { origin: Option<String>, unexpected: Unexpected, expected: &'static str, key: Option<String>, }, At { error: Box<ConfigError>, origin: Option<String>, key: Option<String>, }, Message(String), Foreign(Box<dyn Error + Send + Sync>), }
Represents all possible errors that can occur when working with configuration.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Frozen

Configuration is frozen and no further mutations can be made.



NotFound(String)

Configuration property was not found



PathParse

Configuration path could not be parsed.

Fields

cause: Box<dyn Error + Send + Sync>


FileParse

Configuration could not be parsed from file.

Fields

uri: Option<String>

The URI used to access the file (if not loaded from a string). Example: /path/to/config.json

cause: Box<dyn Error + Send + Sync>

The captured error from attempting to parse the file in its desired format. This is the actual error object from the library used for the parsing.



Type

Value could not be converted into the requested type.

Fields

origin: Option<String>

The URI that references the source that the value came from. Example: /path/to/config.json or Environment or etcd://localhost

unexpected: Unexpected

What we found when parsing the value

expected: &'static str

What was expected when parsing the value

key: Option<String>

The key in the configuration hash of this value (if available where the error is generated).



At

Custom message

Fields

error: Box<ConfigError>

Error being extended with a path

origin: Option<String>

The URI that references the source that the value came from. Example: /path/to/config.json or Environment or etcd://localhost

key: Option<String>

The key in the configuration hash of this value (if available where the error is generated).



Message(String)

Custom message



Foreign(Box<dyn Error + Send + Sync>)

Unadorned error from a foreign origin.